==> apache-cxf-3.4.5-src.tar.gz: apache-cxf-3.4.5-src/rt/rs/extensions/providers/src/test/java/org/apache/cxf/jaxrs/resources/TagVO.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.jaxrs.resources;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;

@XmlRootElement
public class TagVO {
    private String name;
    private String group;
    private Integer attrInt;
    public TagVO() {

    }

    public TagVO(String name, String group) {
        this.name = name;
        this.group = group;
    }

    public void setName(String n) {
        this.name = n;
    }

    public void setGroup(String g) {
        this.group = g;
    }

    public String getName() {
        return name;
    }

    public String getGroup() {
        return group;
    }

    @XmlAttribute
    public Integer getAttrInt() {
        return attrInt;
    }

    public void setAttrInt(Integer attrInt) {
        this.attrInt = attrInt;
    }

}

==> apache-cxf-4.0.7-src.tar.gz: apache-cxf-4.0.7-src/rt/rs/extensions/providers/src/test/java/org/apache/cxf/jaxrs/resources/TagVO.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.jaxrs.resources;

import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlRootElement;

@XmlRootElement
public class TagVO {
    private String name;
    private String group;
    private Integer attrInt;
    public TagVO() {

    }

    public TagVO(String name, String group) {
        this.name = name;
        this.group = group;
    }

    public void setName(String n) {
        this.name = n;
    }

    public void setGroup(String g) {
        this.group = g;
    }

    public String getName() {
        return name;
    }

    public String getGroup() {
        return group;
    }

    @XmlAttribute
    public Integer getAttrInt() {
        return attrInt;
    }

    public void setAttrInt(Integer attrInt) {
        this.attrInt = attrInt;
    }

}
